@@ -59,6 +59,7 @@ def record(func, c, *args, **kwargs):
     rt = None
     try:
         rt = func(c, *args, **kwargs)
+        c.recordLogs()
     except Exception as e:
         cprint(
             colored(
@@ -67,8 +68,9 @@ def record(func, c, *args, **kwargs):
             )
         )
         c.addLog("ERROR: %s" % str(e))
-    finally:
         c.recordLogs()
+        raise
+    
     return rt
  
 # patch 
@@ -204,4 +206,6 @@ def configureDjango(*args, **kws):
     from django.utils.functional import empty
 
     djangoSettings._wrapped = empty
-    djangoSettings.configure(*args, **kws)
\ No newline at end of file
+    djangoSettings.configure(*args, **kws)
+    
+    django.setup()
\ No newline at end of file
